@@ -289,13 +289,13 @@ class EventbridgeToSnsProps:
         :param topic_props: User provided props to override the default props for the SNS Topic. Default: - Default props are used
         '''
         if isinstance(event_rule_props, dict):
-            event_rule_props = RuleProps(**event_rule_props)
+            event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
         if isinstance(encryption_key_props, dict):
-            encryption_key_props = KeyProps(**encryption_key_props)
+            encryption_key_props = aws_cdk.aws_kms.KeyProps(**encryption_key_props)
         if isinstance(event_bus_props, dict):
-            event_bus_props = EventBusProps(**event_bus_props)
+            event_bus_props = aws_cdk.aws_events.EventBusProps(**event_bus_props)
         if isinstance(topic_props, dict):
-            topic_props = TopicProps(**topic_props)
+            topic_props = aws_cdk.aws_sns.TopicProps(**topic_props)
         if __debug__:
             type_hints = typing.get_type_hints(EventbridgeToSnsProps.__init__)
             check_type(argname="argument event_rule_props", value=event_rule_props, expected_type=type_hints["event_rule_props"])
